pub struct LocaleId {
pub id: String,
}Expand description
Typed identifier for a single Locale, which is a set of internationalization-related properties.
Most APIs that consume locales will probably want to accept a vector of locales to account for priority.
Fields
id: StringUnicode BCP-47 Locale Identifier (http://www.unicode.org/reports/tr35/#BCP_47_Conformance).
Must be canonicalized and well-formed. This field should not be populated from arbitrary user- or third-party input, but instead generated programmatically.
Includes language, region, script, and variant, plus Unicode extensions (under the “u” singleton). Other extensions are allowed but ignored.
Examples: “en-US” American English “fr-u-hc-h12” French, with 12-hour clock “ar-EG-u-fw-mon-nu-latn” Egyptian Arabic with “Latin” numerals and first day of week on Monday